# GetAudioChaptersRes


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**num_chapters** | **int** |  | 

## Example

```python
from openapi_client.models.get_audio_chapters_res import GetAudioChaptersRes

# TODO update the JSON string below
json = "{}"
# create an instance of GetAudioChaptersRes from a JSON string
get_audio_chapters_res_instance = GetAudioChaptersRes.from_json(json)
# print the JSON string representation of the object
print(GetAudioChaptersRes.to_json())

# convert the object into a dict
get_audio_chapters_res_dict = get_audio_chapters_res_instance.to_dict()
# create an instance of GetAudioChaptersRes from a dict
get_audio_chapters_res_from_dict = GetAudioChaptersRes.from_dict(get_audio_chapters_res_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


